@@ -491,7 +491,7 @@ class Model:
 
             # Try to get the item in DB
             name_count = missing_names = 0
-            for name in vars(self.__class__):
+            for name in dir(self.__class__):
                 if name.startswith('_'): continue
 
                 attr = getattr(self.__class__, name)
